<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
class LLMS_Payment_Gateway_Aqayepardakht extends LLMS_Payment_Gateway {
    const REDIRECT_URL = 'https://panel.aqayepardakht.ir/startpay/';
    const MIN_AMOUNT = 100;
    public $MerchantID = '';
    public function __construct() {
        $this->id = 'Aqayepardakht';
        $this->icon = '<img src="'.plugins_url('/images/Aqayepardakht.png', __FILE__).'" style="width: 22px; height: 22px;">';
        $this->admin_description = __( 'پرداخت دوره ها و عضویت ها با درگاه آقای پرداخت', 'lifterlms-Aqayepardakht' );
        $this->admin_title = 'درگاه آقای پرداخت';
        $this->title = 'درگاه آقای پرداخت';
        $this->description = __( 'پرداخت امن توسط درگاه آقای پرداخت', 'lifterlms-Aqayepardakht' );
        $this->supports = array(
            'single_payments' => true,
        );
        add_filter( 'llms_get_gateway_settings_fields', array( $this, 'settings_fields' ), 10, 2 );
        add_action( 'lifterlms_checkout_confirm_after_payment_method', array( $this, 'after_payment_method_details' ) );
    }
    public function after_payment_method_details() {
        $key = isset( $_GET['order'] ) ? $_GET['order'] : '';

        $order = llms_get_order_by_key( $key );
        if ( ! $order || 'Aqayepardakht' !== $order->get( 'payment_gateway' ) ) {
            return;
        }
        echo '<input name="llms_aqayepardakht_token" type="hidden" value="' . $_POST['transid'] . '">';
    }
    public function confirm_pending_order( $order ) {
        if ( ! $order || 'Aqayepardakht' !== $order->get( 'payment_gateway' ) ) {
            return;
        }
        $this->log( 'Aqayepardakht `after_payment_method_callback()` started', $order, $_POST );
		if(isset($_POST["llms_aqayepardakht_token"]) ? $_POST["llms_aqayepardakht_token"]: '');
        $params = array('amount' => $order->get_price( 'total', array(), 'float' )/10,'transid' => $_POST["llms_aqayepardakht_token"], 'pin' => self::get_MerchantID());
        $url = 'https://panel.aqayepardakht.ir/api/verify/';
		$fields_string = "";
		foreach($params as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
		rtrim($fields_string, '&');
		$ch = curl_init();
		curl_setopt($ch,CURLOPT_URL, $url);
		curl_setopt($ch,CURLOPT_POST, count($params));
		curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		$result = curl_exec($ch);
		curl_close($ch);
        if ($result > '0') {
            $txn_data = array();
            $txn_data['amount'] = $order->get_price( 'total', array(), 'float' )/10;
            $txn_data['transaction_id'] = $_POST["llms_aqayepardakht_token"];
            $txn_data['status'] = 'llms-txn-succeeded';
            $txn_data['payment_type'] = 'single';
            $txn_data['source_description'] = isset( $_POST['card_holder'] ) ? $_POST['card_holder'] : '';
            $order->record_transaction( $txn_data );
            $this->log( $order, 'Aqayepardakht `confirm_pending_order()` finished' );
            $order->add_note(' تراکنش موفق و شماره تراکنش : ' . $_POST["llms_aqayepardakht_token"] );
            $this->complete_transaction( $order );
        }else{
            $this->log( $order, 'Aqayepardakht `confirm_pending_order()` finished with error : ' . $result );
            $order->add_note(' شماره تراکنش : ' . $_POST["llms_aqayepardakht_token"] );
            wp_safe_redirect( llms_cancel_payment_url() );
            exit();
        }
    }
    public function get_MerchantID() {
        return $this->get_option( 'MerchantID' );
    }
    public function handle_pending_order( $order, $plan, $person, $coupon = false ) {
        $this->log( 'Aqayepardakht `handle_pending_order()` started', $order, $plan, $person, $coupon );
        $total = $order->get_price( 'total', array(), 'float' );
        if ( $total < self::MIN_AMOUNT ) {
            return llms_add_notice( sprintf( __( 'با توجه به محدوديت هاي شاپرك امكان پرداخت با رقم درخواست شده ميسر نمي باشد حداقل مبلغ پرداختی  %s تومان است', 'lifterlms-Aqayepardakht' ), self::MIN_AMOUNT ), 'error' );
        }
        $params = array(
			'amount' => $order->get_price( 'total', array(), 'float'  ) /10,
			'pin' => self::get_MerchantID(),
            'callback' => llms_confirm_payment_url( $order->get( 'order_key' )),
			'invoice_id'=> $order->get( 'order_key' ),
            'description' => 'خرید توسط : '. $order->get_customer_name() . ' | ایمیل خریدار : '. $order->get( 'billing_email' ));
		$url = 'https://panel.aqayepardakht.ir/api/create/';
		$fields_string = "";
		foreach($params as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
		rtrim($fields_string, '&');
		$ch = curl_init();
		curl_setopt($ch,CURLOPT_URL, $url);
		curl_setopt($ch,CURLOPT_POST, count($params));
		curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		$result = curl_exec($ch);
		curl_close($ch);
        if($result > '1')
        {
            $this->log( $result, 'Aqayepardakht `handle_pending_order()` finished' );
            do_action( 'lifterlms_handle_pending_order_complete', $order );
            $order->add_note('تراکنش ناموفق');
            wp_redirect( self::REDIRECT_URL . $result );
            exit();
        }
        else
        {
            $this->log( $result, 'Aqayepardakht `handle_pending_order()` finished with error code : ' );
            return llms_add_notice( 'خطا در اتصال به درگاه : ' . $result , 'error' );
        }

    }
    public function settings_fields( $fields, $gateway_id ) {
        if ( $this->id !== $gateway_id ) {
            return $fields;
        }
        $fields[] = array(
            'type'  => 'custom-html',
            'value' => '
				<h4>' . __( 'Aqayepardakht Settings', 'lifterlms-Aqayepardakht' ) . '</h4>
				<p>' . __( 'پین درگاه خود را برای اتصال به درگاه آقای پرداخت وارد نمایید.', 'lifterlms-Aqayepardakht' ) . '</p>
			',
        );
        $settings = array(
            'MerchantID' => __( 'پین درگاه', 'lifterlms-Aqayepardakht' ),
        );
        foreach( $settings as $k => $v ) {
            $fields[] = array(
                'id'            => $this->get_option_name( $k ),
                'default'       => $this->{'get_' . $k}(),
                'title'         => $v,
                'type'          => 'text',
            );
        }
        return $fields;

    }

}